Package: ggnetwork
Type: Package
Title: Geometries to Plot Networks with 'ggplot2'
Description: Geometries to plot network objects with 'ggplot2'.
Version: 0.5.13
Date: 2024-02-14
Maintainer: François Briatte <f.briatte@gmail.com>
Authors@R: c(
  person("François", "Briatte", email = "f.briatte@gmail.com", role = c("aut", "cre"), comment = c(ORCID = "0000-0001-6494-9774")),
  person("Michał", "Bojanowski", role = "ctb", comment = c(ORCID = "0000-0001-7503-852X")),
  person("Mickaël", "Canouil", role = "ctb", comment = c(ORCID = "0000-0002-3396-4549")),
  person("Zachary", "Charlop-Powers", role = "ctb", comment = c(ORCID = "0000-0001-8816-4680")),
  person("Jacob C.", "Fisher", role = "ctb", comment = c(ORCID = "0000-0003-0299-0346")),
  person("Kipp", "Johnson", role = "ctb", comment = c(ORCID = "0000-0002-5102-741X")),
  person("Tyler", "Rinker", role = "ctb")
  )
License: GPL-3
URL: https://github.com/briatte/ggnetwork
BugReports: https://github.com/briatte/ggnetwork/issues
Depends: R (>= 3.5), ggplot2 (>= 2.0.0)
Imports: ggrepel (>= 0.5), network, igraph, sna, utils
Suggests: knitr, rmarkdown, testthat
Collate: 'utilities.R' 'fortify-igraph.R' 'fortify-network.R'
        'geom-nodes.R' 'geom-edges.R' 'ggnetwork.R'
VignetteBuilder: knitr
RoxygenNote: 7.3.1
Encoding: UTF-8
NeedsCompilation: no
Packaged: 2024-02-14 10:17:48 UTC; fr
Author: François Briatte [aut, cre] (<https://orcid.org/0000-0001-6494-9774>),
  Michał Bojanowski [ctb] (<https://orcid.org/0000-0001-7503-852X>),
  Mickaël Canouil [ctb] (<https://orcid.org/0000-0002-3396-4549>),
  Zachary Charlop-Powers [ctb] (<https://orcid.org/0000-0001-8816-4680>),
  Jacob C. Fisher [ctb] (<https://orcid.org/0000-0003-0299-0346>),
  Kipp Johnson [ctb] (<https://orcid.org/0000-0002-5102-741X>),
  Tyler Rinker [ctb]
Repository: CRAN
Date/Publication: 2024-02-14 11:20:02 UTC
Built: R 4.4.0; ; 2024-05-30 03:29:53 UTC; unix
