# Generated by roxygen2: do not edit by hand

S3method(fortify,igraph)
S3method(fortify,network)
export(fortify)
export(geom_edgelabel)
export(geom_edgelabel_repel)
export(geom_edges)
export(geom_edgetext)
export(geom_edgetext_repel)
export(geom_nodelabel)
export(geom_nodelabel_repel)
export(geom_nodes)
export(geom_nodetext)
export(geom_nodetext_repel)
export(ggnetwork)
export(theme_blank)
export(theme_facet)
export(unit)
importFrom(ggplot2,fortify)
importFrom(ggplot2,unit)
